@@ -757,7 +757,7 @@ class BaseEnvironnement(BaseEstimator):
                 )
             )
         )
-        state_in_loos_kargs = list(
+        state_in_loss_kargs = list(
             filter(
                 lambda x: x == 'kargs' or x == 'kwargs',
                 (
@@ -777,7 +777,7 @@ class BaseEnvironnement(BaseEstimator):
                 "state sera choisi par défaut."
             )
             loss_kargs['state'] = state
-        elif len(state_in_loos_kargs) == 1:
+        elif len(state_in_loss_kargs) == 1:
             loss_kargs['state'] = state
 
         list_callbacks.begin_train(self, dataset, state, control, None)
