@@ -46,3 +46,15 @@ class DivergenceError(Exception):
     """
     def __init__(self, msg: Optional[str]=None):
         self.msg = msg
+
+class TrainError(Exception):
+    r"""
+    Classe d'erreur quelconque durant l'apprentissage.
+    
+    Parameters
+    ----------
+    msg : Optional[str]
+        message à passer avec l'erreur.
+    """
+    def __init__(self, msg: Optional[str]=None):
+        self.msg = msg
